@@ -7,26 +7,50 @@
  * Routines to handle ASCII mode tranfers. Yuk.
  */
 
-unsigned int
-vsf_ascii_ascii_to_bin(const char* p_in, char* p_out, unsigned int in_len)
+#include "ascii.h"
+
+struct ascii_to_bin_ret
+vsf_ascii_ascii_to_bin(char* p_buf, unsigned int in_len, int prev_cr)
 {
-  /* Task: translate all \r\n into plain \n
-   * For simplicity, I'm cheating and just ripping out all \r. If someone
-   * complains about it breaking something, it'll get fixed.
+  /* Task: translate all \r\n into plain \n. A plain \r not followed by \n must
+   * not be removed.
    */
+  struct ascii_to_bin_ret ret;
   unsigned int indexx = 0;
   unsigned int written = 0;
+  char* p_out = p_buf + 1;
+  ret.last_was_cr = 0;
+  if (prev_cr && (!in_len || p_out[0] != '\n'))
+  {
+    p_buf[0] = '\r';
+    ret.p_buf = p_buf;
+    written++;
+  }
+  else
+  {
+    ret.p_buf = p_out;
+  }
   while (indexx < in_len)
   {
-    char the_char = p_in[indexx];
+    char the_char = p_buf[indexx + 1];
     if (the_char != '\r')
     {
       *p_out++ = the_char;
       written++;
     }
+    else if (indexx == in_len - 1)
+    {
+      ret.last_was_cr = 1;
+    }
+    else if (p_buf[indexx + 2] != '\n')
+    {
+      *p_out++ = the_char;
+      written++;
+    }
     indexx++;
   }
-  return written;
+  ret.stored = written;
+  return ret;
 }
 
 unsigned int
