@@ -1,6 +1,6 @@
 /*
  * Part of Very Secure FTPd
- * Licence: GPL
+ * Licence: GPL v2
  * Author: Chris Evans
  * sysstr.c
  *
@@ -40,6 +40,13 @@ str_write_loop(const struct mystr* p_str, const int fd)
   return vsf_sysutil_write_loop(fd, str_getbuf(p_str), str_getlen(p_str));
 }
 
+int
+str_read_loop(struct mystr* p_str, const int fd)
+{
+  return vsf_sysutil_read_loop(
+    fd, (char*) str_getbuf(p_str), str_getlen(p_str));
+}
+
 int
 str_mkdir(const struct mystr* p_str, const unsigned int mode)
 {
